==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fSG.h <==
// public class gnu.java.locale.LocaleInformation_en_SG

// class file dependencies
// @dep_class c1cbd487b916fb43 gnu_java_locale_LocaleInformation__5fen__5fSG
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*zoneStrings;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods	gnu_java_locale_LocaleInformation__5fen__5fSG;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fSG;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fSG;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fSG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fSG.h <==
// public class gnu.java.locale.LocaleInformation_en_SG

// class file dependencies
// @dep_class c1cbd487b916fb43 gnu_java_locale_LocaleInformation__5fen__5fSG
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*zoneStrings;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vmethods	gnu_java_locale_LocaleInformation__5fen__5fSG;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fSG;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fSG;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fSG$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fSG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fSG$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fSG_H_ */
